@@ -1,4 +1,4 @@
-# Copyright (c) 2016-2022 by Ron Frederick <ronf@timeheart.net> and others.
+# Copyright (c) 2016-2025 by Ron Frederick <ronf@timeheart.net> and others.
 #
 # This program and the accompanying materials are made available under
 # the terms of the Eclipse Public License v2.0 which accompanies this
@@ -36,7 +36,8 @@ from asyncssh.public_key import CERT_TYPE_USER, CERT_TYPE_HOST
 
 from .keysign_stub import create_subprocess_exec_stub
 from .server import Server, ServerTestCase
-from .util import asynctest, gss_available, patch_getnameinfo, patch_gss
+from .util import asynctest, gss_available, patch_getnameinfo
+from .util import patch_getnameinfo_error, patch_gss
 from .util import make_certificate, nc_available, x509_available
 
 
@@ -74,6 +75,9 @@ class _NullServer(Server):
 
         return False
 
+    async def auth_completed(self):
+        """Handle client authentication request"""
+
 
 class _HostBasedServer(Server):
     """Server for testing host-based authentication"""
@@ -413,11 +417,11 @@ class _AsyncKbdintServer(_KbdintServer):
 class _UnknownAuthClientConnection(asyncssh.connection.SSHClientConnection):
     """Test getting back an unknown auth method from the SSH server"""
 
-    def try_next_auth(self):
+    def try_next_auth(self, *, next_method=False):
         """Attempt client authentication using an unknown method"""
 
         self._auth_methods = [b'unknown'] + self._auth_methods
-        super().try_next_auth()
+        super().try_next_auth(next_method=next_method)
 
 
 class _TestNullAuth(ServerTestCase):
@@ -860,6 +864,26 @@ class _TestHostBasedAuth(ServerTestCase):
                                disable_trivial_auth=True)
 
 
+class _TestHostBasedAuthNoRDNS(ServerTestCase):
+    """Unit tests for host-based authentication with no reverse DNS"""
+
+    @classmethod
+    async def start_server(cls):
+        """Start an SSH server which supports host-based authentication"""
+
+        return await cls.create_server(
+            _HostBasedServer, known_client_hosts='known_hosts')
+
+    @patch_getnameinfo_error
+    @asynctest
+    async def test_client_host_auth_no_rdns(self):
+        """Test connecting with host-based authentication with no RDNS"""
+
+        async with self.connect(username='user', client_host_keys='skey',
+                                client_username='user'):
+            pass
+
+
 @patch_getnameinfo
 class _TestCallbackHostBasedAuth(ServerTestCase):
     """Unit tests for host-based authentication using callback"""
@@ -1259,7 +1283,8 @@ class _TestPublicKeyAuth(ServerTestCase):
     async def test_agent_auth_unset(self):
         """Test connecting with no local keys and no ssh-agent configured"""
 
-        with patch.dict(os.environ, HOME='xxx', SSH_AUTH_SOCK=''):
+        with patch.dict(os.environ, HOME='xxx', USERPROFILE='xxx',
+                        SSH_AUTH_SOCK=''):
             with self.assertRaises(asyncssh.PermissionDenied):
                 await self.connect(username='ckey',
                                    known_hosts='.ssh/known_hosts')
