@@ -1,4 +1,4 @@
-# Copyright (c) 2015-2018 by Ron Frederick <ronf@timeheart.net> and others.
+# Copyright (c) 2015-2024 by Ron Frederick <ronf@timeheart.net> and others.
 #
 # This program and the accompanying materials are made available under
 # the terms of the Eclipse Public License v2.0 which accompanies this
@@ -108,7 +108,7 @@ class _TestKnownHosts(TempDirTestCase):
 
         for prefix, patlist, keys in zip(prefixes, patlists, self.keylists):
             for pattern, key in zip(patlist, keys):
-                known_hosts += '%s%s %s' % (prefix, pattern, key)
+                known_hosts += f'{prefix}{pattern} {key}'
 
         if from_file:
             with open('known_hosts', 'w') as f:
